==> tuia-treasure-center-api-1.8.0.3-RELEASE-sources.jar: cn/tuia/tuia/treasure/center/api/enums/SlotPositionConfig.java <==
package cn.tuia.tuia.treasure.center.api.enums;


/**
 * Created by xuefeng on 2018/12/19.
 */
public enum SlotPositionConfig {

    /**
     * 广点通三图
     */
    GDT_THREE(0),

    /**
     * 广点通小图
     */
    GDT_SMALL(1),

    /**
     * 广点通大图
     */
    GDT_BIG(2),

    /**
     * 广点通顶部横幅
     */
    GDT_TOP_BANNER(3),

    /**
     * 广点通底部横幅
     */
    GDT_DOWN_BANNER(4),

    /**
     * 百度大图
     */
    BAIDU_BIG(5),

    /**
     * 百度小图
     */
    BAIDU_SMALL(6),

    /**
     * 推啊互动
     */
    TUIA_INTERACT(7),

    /**
     * 推啊大图
     */
    TUIA_BIG(8),

    /**
     * 推啊小图
     */
    TUIA_SMALL(9),

    /**
     * 百度顶部横幅
     */
    BAIDU_TOP_BANNER(10),

    /**
     * 百度底部横幅
     */
    BAIDU_DOWN_BANNER(11);

    private Integer type;

    SlotPositionConfig(Integer type) {
        this.type = type;
    }

    public Integer getType() {
        return type;
    }

    public static SlotPositionConfig getByType(Integer type) {
        for (SlotPositionConfig slotPositionConfig : SlotPositionConfig.values()) {
            if(slotPositionConfig.getType().equals(type)) {
                return slotPositionConfig;
            }
        }
        //降级推啊互动
        return TUIA_INTERACT;
    }

    //三图模式
    public Boolean isThree() {
        return this.equals(GDT_THREE);
    }

    //广点通
    public Boolean isGdt() {
        return this.equals(GDT_THREE) || this.equals(GDT_BIG) || this.equals(GDT_SMALL) || this.equals(GDT_TOP_BANNER) || this.equals(GDT_DOWN_BANNER);
    }

    //百度
    public Boolean isBaidu() {
        return this.equals(BAIDU_BIG) || this.equals(BAIDU_SMALL) || this.equals(BAIDU_TOP_BANNER) || this.equals(BAIDU_DOWN_BANNER);
    }

    //推啊直投
    public Boolean isTuiaDirect() {
        return this.equals(TUIA_BIG) || this.equals(TUIA_SMALL);
    }

    //大图
    public Boolean isBig() {
        return this.equals(GDT_BIG) || this.equals(BAIDU_BIG) || this.equals(TUIA_BIG);
    }

    //小图
    public Boolean isSmall() {
        return this.equals(GDT_SMALL) || this.equals(BAIDU_SMALL) || this.equals(TUIA_SMALL);
    }
}

==> tuia-treasure-center-api-2.9.0.0-RELEASE-sources.jar: cn/tuia/tuia/treasure/center/api/enums/SlotPositionConfig.java <==
package cn.tuia.tuia.treasure.center.api.enums;


/**
 * Created by xuefeng on 2018/12/19.
 */
public enum SlotPositionConfig {

    /**
     * 广点通三图
     */
    GDT_THREE(0),

    /**
     * 广点通小图
     */
    GDT_SMALL(1),

    /**
     * 广点通大图
     */
    GDT_BIG(2),

    /**
     * 广点通顶部横幅
     */
    GDT_TOP_BANNER(3),

    /**
     * 广点通底部横幅
     */
    GDT_DOWN_BANNER(4),

    /**
     * 百度大图
     */
    BAIDU_BIG(5),

    /**
     * 百度小图
     */
    BAIDU_SMALL(6),

    /**
     * 推啊互动
     */
    TUIA_INTERACT(7),

    /**
     * 推啊大图
     */
    TUIA_BIG(8),

    /**
     * 推啊小图
     */
    TUIA_SMALL(9),

    /**
     * 百度顶部横幅
     */
    BAIDU_TOP_BANNER(10),

    /**
     * 百度底部横幅
     */
    BAIDU_DOWN_BANNER(11),

    /**
     * tuia活动工具
     */
    TUIA_ACTIVITY(12);

    private Integer type;

    SlotPositionConfig(Integer type) {
        this.type = type;
    }

    public Integer getType() {
        return type;
    }

    public static SlotPositionConfig getByType(Integer type) {
        for (SlotPositionConfig slotPositionConfig : SlotPositionConfig.values()) {
            if(slotPositionConfig.getType().equals(type)) {
                return slotPositionConfig;
            }
        }
        //降级推啊互动
        return TUIA_INTERACT;
    }

    //三图模式
    public Boolean isThree() {
        return this.equals(GDT_THREE);
    }

    //广点通
    public Boolean isGdt() {
        return this.equals(GDT_THREE) || this.equals(GDT_BIG) || this.equals(GDT_SMALL) || this.equals(GDT_TOP_BANNER) || this.equals(GDT_DOWN_BANNER);
    }

    //百度
    public Boolean isBaidu() {
        return this.equals(BAIDU_BIG) || this.equals(BAIDU_SMALL) || this.equals(BAIDU_TOP_BANNER) || this.equals(BAIDU_DOWN_BANNER);
    }

    //推啊直投
    public Boolean isTuiaDirect() {
        return this.equals(TUIA_BIG) || this.equals(TUIA_SMALL);
    }

    //大图
    public Boolean isBig() {
        return this.equals(GDT_BIG) || this.equals(BAIDU_BIG) || this.equals(TUIA_BIG);
    }

    //小图
    public Boolean isSmall() {
        return this.equals(GDT_SMALL) || this.equals(BAIDU_SMALL) || this.equals(TUIA_SMALL);
    }

    //tuia活动工具
    public Boolean isTuiaActivity() {
        return this.equals(TUIA_ACTIVITY);
    }
}
